set terminal epslatex color dashed

set ytics autofreq
unset xlabel
unset ylabel
unset logscale
unset xrange
unset yrange
unset log y


###############################################################
# LHC10TeV W/Z  ratios  born  muon  bare    transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'LHC10TeV' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_xmt1_born_norec_200.dat\
              horace/born-LHC10-Z-mu-bare/lhc_z_mu_xmt2_born_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_xm_lhc.dat\
              wzgrad/nc_lhc/nc_xm_lhc.dat"\
      u 1:($2/$5) w his lw 2 lt 2 title '{\tt WZGRAD}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-Xmt.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-Xmt.eps"


###############################################################
# LHC10TeV W/Z  ratios  born  muon  bare    transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'LHC10TeV' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_xptl1_born_norec_200.dat\
              horace/born-LHC10-Z-mu-bare/lhc_z_mu_xptl2_born_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_xpt_lhc.dat\
              wzgrad/nc_lhc/nc_xpt_lhc.dat"\
      u 1:($2/$5) w his lw 2 lt 2 title '{\tt WZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-Xptl.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-Xptl.eps"




###############################################################
# LHC10TeV W+ production  born  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,18
set label 'muon' at 55,16

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_mtv1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_mt_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}',\
     "< paste dkm/cc_lhc/histo_born_MT_nul"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-mtw.eps "

system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-mtw.eps"

###############################################################
# LHC10TeV W+ production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'LHC10TeV' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ptl1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_ptl1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}',\
     "< paste dkm/cc_lhc/histo_born_pt_l"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ptl.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ptl.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'LHC10TeV' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ptn1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_ptl2_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}',\
     "< paste dkm/cc_lhc/histo_born_pt_miss"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ptnu.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ptnu.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_etal_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_etal1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}',\
     "< paste dkm/cc_lhc/histo_born_eta_l"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-etal.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-etal.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_costh*_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_costl1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-costh.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-costh.eps"





###############################################################
# LHC10TeV Z  production  born  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'LHC10TeV' at 120,7
set label 'bare cuts' at 120,6
set label 'muon' at 120,5

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_minv_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_minv_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-minv.eps "

system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-minv.eps"

###############################################################
# LHC10TeV Z  production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'LHC10TeV' at 30,6
set label 'bare cuts' at 30,5
set label 'muon' at 30,4

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_ptl1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_ptl1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-ptl.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-ptl.eps"



###############################################################
# LHC10TeV Z  production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'LHC10TeV' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_etal_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_etal1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-etal.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-etal.eps"



###############################################################
# LHC10TeV Z  production  born  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'LHC10TeV' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_yv_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_yZ_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-yz.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-yz.eps"


###############################################################
# LHC10TeV Z  production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_costh*2_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_costl1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-costh.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-costh.eps"



################################################################
#  O(alpha)
################################################################

###############################################################
# LHC10TeV W/Z  ratios  oal  muon  bare    transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'LHC10TeV' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_xmt1_oal_norec_200.dat\
              horace/oal-LHC10-Z-mu-bare/lhc_z_mu_xmt2_oal_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-Xmt.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-Xmt.eps"


###############################################################
# LHC10TeV W/Z  ratios  oal  muon  bare    transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'LHC10TeV' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_xptl1_oal_norec_200.dat\
              horace/oal-LHC10-Z-mu-bare/lhc_z_mu_xptl2_oal_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-Xptl.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-Xptl.eps"




###############################################################
# LHC10TeV W+ production  oal  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,18
set label 'muon' at 55,16

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_mtv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_MTln.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_MT_nul"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-mtw.eps "

system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-mtw.eps"

###############################################################
# LHC10TeV W+ production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'LHC10TeV' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ptl1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ptlp.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_pt_l"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ptl.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ptl.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'LHC10TeV' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ptn1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ptnu.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ptnu.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ptnu.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_etal_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_etal.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_eta_l"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-etal.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-etal.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_costh*_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ctlp.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-costh.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-costh.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ptv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ptW1.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ptW1.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ptW1.eps"



###############################################################
# LHC10TeV W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ptv2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ptW2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ptW2.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ptW2.eps"




###############################################################
# LHC10TeV W+ production  oal  muon  bare   photon energy
set autoscale
set output "plot.eps"

set key top right
set xrange [0:50]
#set yrange [0.9:1.35]

set xlabel '$E_{\gamma}$ (GeV) '
set ylabel '$\frac{d\sigma}{dE_\gamma}(pb/GeV)$'
set label 'LHC10TeV' at 25,20
set label 'bare cuts' at 25,17
set label 'muon' at 25,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_eneg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_Egam.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_E_g"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-Eg.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-Eg.eps"

###############################################################
# LHC10TeV W+ production  oal  muon  bare   photon transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\gamma$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\gamma}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ptg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ptga.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_pt_g"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ptg.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ptg.eps"



###############################################################
# LHC10TeV W+ production  oal  muon  bare   sqrt{R_lg}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$\sqrt{R_{l\gamma}}$  '
set ylabel '$\frac{d\sigma}{d\sqrt{R_{l\gamma}}}(pb)$'
set label 'LHC10TeV' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_sqrRlg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_Rlga.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-sqrtRlg.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-sqrtRlg.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare   log_10(R_lg)
set autoscale
set output "plot.eps"

set key top right
set xrange [-6:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(R_{l\gamma})$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(R_{l\gamma})}(pb)$'
set label 'LHC10TeV' at -4,20
set label 'bare cuts' at -4,17
set label 'muon' at -4,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_logRlg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_Rlg2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-logRlg.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-logRlg.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$y^{(1/3)}$  '
set ylabel '$\frac{d\sigma}{dy^{(1/3)}}(pb)$'
set label 'LHC10TeV' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_ycr_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_ygam.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-ycr.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-ycr.eps"


###############################################################
# LHC10TeV W+ production  oal  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [-4:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(y)$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(y)}(pb)$'
set label 'LHC10TeV' at -2,20
set label 'bare cuts' at -2,17
set label 'muon' at -2,14

plot "< paste horace/oal-LHC10-Wp-mu-bare/lhc_w_mu_logy_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_lhc_bare_ds001_yga2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste dkm/cc_lhc/histo_LHC_Wp_corrections_y_lg"\
      u 1:($2/1000) w his lw 2 lt 3 title '{\tt DKM} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Wp-mu-bare-logy.eps "
system "epstopdf figures-LHC10/oal-LHC10-Wp-mu-bare-logy.eps"




###############################################################
# LHC10TeV Z  production  oal  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'LHC10TeV' at 120,7
set label 'bare cuts' at 120,6
set label 'muon' at 120,5

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_minv_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-minv.eps "

system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-minv.eps"

###############################################################
# LHC10TeV Z  production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'LHC10TeV' at 30,6
set label 'bare cuts' at 30,5
set label 'muon' at 30,4

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_ptl1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-ptl.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-ptl.eps"



###############################################################
# LHC10TeV Z  production  oal  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'LHC10TeV' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_etal_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-etal.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-etal.eps"



###############################################################
# LHC10TeV Z  production  oal  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'LHC10TeV' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_yv_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-yz.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-yz.eps"


###############################################################
# LHC10TeV Z  production  oal  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'LHC10TeV' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_costh*2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-costh.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-costh.eps"


###############################################################
# LHC10TeV Z  production  oal  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 15,20
set label 'bare cuts' at 15,17
set label 'muon' at 15,14

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_ptv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-ptZ1.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-ptZ1.eps"



###############################################################
# LHC10TeV Z  production  oal  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-LHC10-Z-mu-bare/lhc_z_mu_ptv2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/oal-LHC10-Z-mu-bare-ptZ2.eps "
system "epstopdf figures-LHC10/oal-LHC10-Z-mu-bare-ptZ2.eps"






system "tar -cvzf figures-LHC10.tgz figures-LHC10/"


exit

###############################################################
# LHC10TeV W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ptv1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_ptW1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ptW1.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ptW1.eps"



###############################################################
# LHC10TeV W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ptv2_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_lhc/cc_ptW2_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ptW2.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ptW2.eps"




###############################################################
# LHC10TeV W+ production  born  muon  bare   photon energy
set autoscale
set output "plot.eps"

set key top right
set xrange [0:50]
#set yrange [0.9:1.35]

set xlabel '$E_{\gamma}$ (GeV) '
set ylabel '$\frac{d\sigma}{dE_\gamma}(pb/GeV)$'
set label 'LHC10TeV' at 25,20
set label 'bare cuts' at 25,17
set label 'muon' at 25,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_eneg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-Eg.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-Eg.eps"

###############################################################
# LHC10TeV W+ production  born  muon  bare   photon transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\gamma$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\gamma}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ptg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ptg.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ptg.eps"



###############################################################
# LHC10TeV W+ production  born  muon  bare   sqrt{R_lg}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$\sqrt{R_{l\gamma}}$  '
set ylabel '$\frac{d\sigma}{d\sqrt{R_{l\gamma}}}(pb)$'
set label 'LHC10TeV' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_sqrRlg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-sqrtRlg.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-sqrtRlg.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare   log_10(R_lg)
set autoscale
set output "plot.eps"

set key top right
set xrange [-6:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(R_{l\gamma})$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(R_{l\gamma})}(pb)$'
set label 'LHC10TeV' at -4,20
set label 'bare cuts' at -4,17
set label 'muon' at -4,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_logRlg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-logRlg.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-logRlg.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$y^{(1/3)}$  '
set ylabel '$\frac{d\sigma}{dy^{(1/3)}}(pb)$'
set label 'LHC10TeV' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_ycr_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-ycr.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-ycr.eps"


###############################################################
# LHC10TeV W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [-4:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(y)$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(y)}(pb)$'
set label 'LHC10TeV' at -2,20
set label 'bare cuts' at -2,17
set label 'muon' at -2,14

plot "< paste horace/born-LHC10-Wp-mu-bare/lhc_w_mu_logy_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Wp-mu-bare-logy.eps "
system "epstopdf figures-LHC10/born-LHC10-Wp-mu-bare-logy.eps"


###############################################################
# LHC10TeV Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 15,20
set label 'bare cuts' at 15,17
set label 'muon' at 15,14

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_ptv1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_ptZ1_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-ptZ1.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-ptZ1.eps"



###############################################################
# LHC10TeV Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'LHC10TeV' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-LHC10-Z-mu-bare/lhc_z_mu_ptv2_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/nc_lhc/nc_ptZ2_lhc.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures-LHC10/born-LHC10-Z-mu-bare-ptZ2.eps "
system "epstopdf figures-LHC10/born-LHC10-Z-mu-bare-ptZ2.eps"

