set terminal epslatex color dashed

set ytics autofreq
unset xlabel
unset ylabel
unset logscale
unset xrange
unset yrange
unset log y



###############################################################
# Tevatron W+ production  oal  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set log y

set xlabel '$y^{(1/3)}$  '
set ylabel '$\frac{d\sigma}{dy^{(1/3)}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,3
set label 'muon' at 0.3,0.7

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ycr_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ds001_ygam.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ygam.dat"\
      u 1:2 w his lw 2 lt 3 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ycr.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ycr.eps"

exit

###############################################################
# Tevatron W+ production  oal  muon  bare   log_10(R_lg)
set autoscale
set output "plot.eps"

set key top left
set xrange [-6:0]
#set yrange [0.9:1.35]

set log y

set xlabel '$\log_{10}(R_{l\gamma})$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(R_{l\gamma})}(pb)$'
set label 'Tevatron' at -2,0.02
set label 'bare cuts' at -2,0.007
set label 'muon' at -2,0.002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_logRlg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ds001_Rlg2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste wzgrad/cc_tev/cc_tev_bare_Rlg2.dat"\
      u 1:2 w his lw 2 lt 3 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-logRlg.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-logRlg.eps"




###############################################################
# Tevatron W+ production  oal  muon  bare   photon energy
set autoscale
set output "plot.eps"

set key top right
set xrange [0:50]
set yrange [0.01:250]

set log y

set xlabel '$E_{\gamma}$ (GeV) '
set ylabel '$\frac{d\sigma}{dE_\gamma}(pb/GeV)$'
set label 'Tevatron' at 25,20
set label 'bare cuts' at 25,12
set label 'muon' at 25,8

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_eneg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_Egam.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-Eg.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-Eg.eps"


exit

###############################################################
# Tevatron W+ production  oal  muon  bare   photon transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\gamma$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\gamma}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptga.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptg.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptg.eps"



###############################################################
# Tevatron W+ production  oal  muon  bare   sqrt{R_lg}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$\sqrt{R_{l\gamma}}$  '
set ylabel '$\frac{d\sigma}{d\sqrt{R_{l\gamma}}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_sqrRlg_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ds001_Rlga.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste wzgrad/cc_tev/cc_tev_bare_Rlga.dat"\
      u 1:2 w his lw 2 lt 3 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-sqrtRlg.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-sqrtRlg.eps"



###############################################################
# Tevatron W+ production  oal  muon  bare   log y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [-4:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(y)$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(y)}(pb)$'
set label 'Tevatron' at -2,20
set label 'bare cuts' at -2,17
set label 'muon' at -2,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_logy_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ds001_yga2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD ds001} ',\
     "< paste wzgrad/cc_tev/cc_tev_bare_yga2.dat"\
      u 1:2 w his lw 2 lt 3 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-logy.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-logy.eps"




exit

###############################################################
# Tevatron W/Z  ratios  born  muon  bare    transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xmt1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xmt2_born_norec_200.dat\
              wzgrad/nc_tev/nc_xm_tev.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xmt1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xmt2_born_norec_200.dat\
              wzgrad/cc_tev/cc_xm_tev.dat\
              wzgrad/nc_tev/nc_xm_tev.dat"\
      u 1:($8/$11) w his lw 2 lt 2 title '{\tt WZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-Xmt.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-Xmt.eps"

###############################################################
# Tevatron W/Z  ratios  born  muon  bare    transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,1.006
set label 'bare cuts' at 1,1.004
set label 'muon' at 1,1.002

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xmt1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xmt2_born_norec_200.dat\
              wzgrad/nc_tev/nc_xm_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xmt1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xmt2_born_norec_200.dat\
              wzgrad/cc_tev/cc_xm_tev.dat\
              wzgrad/nc_tev/nc_xm_tev.dat"\
      u 1:($8/$11/$2*$5) w his lw 2 lt 2 title '{\tt WZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-Xmt_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-Xmt_ratio.eps"


###############################################################
# Tevatron W/Z  ratios  born  muon  bare    transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,4.5
set label 'bare cuts' at 1,4.3
set label 'muon' at 1,4.1

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xptl1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xptl2_born_norec_200.dat\
              wzgrad/nc_tev/nc_xpt_tev.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}',\
"< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xptl1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xptl2_born_norec_200.dat\
              wzgrad/cc_tev/cc_xpt_tev.dat\
              wzgrad/nc_tev/nc_xpt_tev.dat"\
      u 1:($8/$11) w his lw 2 lt 2 title '{\tt WZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-Xptl.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-Xptl.eps"


###############################################################
# Tevatron W/Z  ratios  born  muon  bare    transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,1.006
set label 'bare cuts' at 1,1.004
set label 'muon' at 1,1.002

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xptl1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xptl2_born_norec_200.dat\
              wzgrad/nc_tev/nc_xpt_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
"< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_xptl1_born_norec_200.dat\
              horace/born-TeV-Z-mu-bare/tev_z_mu_xptl2_born_norec_200.dat\
              wzgrad/cc_tev/cc_xpt_tev.dat\
              wzgrad/nc_tev/nc_xpt_tev.dat"\
      u 1:($8/$11/$2*$5) w his lw 2 lt 2 title '{\tt WZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-Xptl_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-Xptl_ratio.eps"







###############################################################
# Tevatron Z  production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_etal_born_norec_200.dat\
              wzgrad/nc_tev/nc_etal2_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_etal_born_norec_200.dat\
              wzgrad/nc_tev/nc_etal2_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-etal.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-etal.eps"


###############################################################
# Tevatron Z  production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,1.0006
set label 'bare cuts' at 0,1.0004
set label 'muon' at 0,1.0002

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_etal_born_norec_200.dat\
              wzgrad/nc_tev/nc_etal2_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_etal_born_norec_200.dat\
              wzgrad/nc_tev/nc_etal2_tev.dat"\
      u 4:($5/$2) w his lw 2 lt 2 title '{\tt ZGRAD}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-etal_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-etal_ratio.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_yv_born_norec_200.dat\
              wzgrad/nc_tev/nc_yZ_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_yv_born_norec_200.dat\
              wzgrad/nc_tev/nc_yZ_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-yz.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-yz.eps"

###############################################################
# Tevatron Z  production  born  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'Tevatron' at 0,1.0006
set label 'bare cuts' at 0,1.0004
set label 'muon' at 0,1.0002

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_yv_born_norec_200.dat\
              wzgrad/nc_tev/nc_yZ_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_yv_born_norec_200.dat\
              wzgrad/nc_tev/nc_yZ_tev.dat"\
      u 4:($5/$2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-yz_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-yz_ratio.eps"





###############################################################
# Tevatron W+ production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_etal_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_etal1_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-etal.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-etal.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,1.0006
set label 'bare cuts' at 0,1.0004
set label 'muon' at 0,1.0002

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_etal_born_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_etal_born_norec_200.dat\
              wzgrad/cc_tev/cc_etal1_tev.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-etal_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-etal_ratio.eps"




###############################################################
# Tevatron W+ production  born  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,1.006
set label 'bare cuts' at 45,1.004
set label 'muon' at 45,1.002

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptn1_born_norec_100.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptn1_born_norec_200.dat\
              wzgrad/cc_tev/cc_ptl2_tev.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptnu_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptnu_ratio.eps"



###############################################################
# Tevatron W+ production  born  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,18
set label 'muon' at 55,16

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_mtv1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_mt_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-mtw.eps "

system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-mtw.eps"

###############################################################
# Tevatron W+ production  born  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,1.008
set label 'bare cuts' at 55,1.007
set label 'muon' at 55,1.006

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_mtv1_born_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_mtv1_born_norec_200.dat\
              wzgrad/cc_tev/cc_mt_tev.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-mtw_ratio.eps "

system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-mtw_ratio.eps"






###############################################################
# Tevatron W+ production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptl1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_ptl1_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptl.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptl.eps"

###############################################################
# Tevatron W+ production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,1.006
set label 'bare cuts' at 45,1.005
set label 'muon' at 45,1.004

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptl1_born_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptl1_born_norec_200.dat\
              wzgrad/cc_tev/cc_ptl1_tev.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptl_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptl_ratio.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptn1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_ptl2_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptnu.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptnu.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_costh*_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_costl2_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-costh.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-costh.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,1.006
set label 'bare cuts' at 0,1.004
set label 'muon' at 0,1.002

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_costh*_born_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_costh*_born_norec_200.dat\
              wzgrad/cc_tev/cc_costl2_tev.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-costh_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-costh_ratio.eps"





###############################################################
# Tevatron Z  production  born  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'Tevatron' at 120,7
set label 'bare cuts' at 120,6
set label 'muon' at 120,5

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_minv_born_norec_200.dat\
              wzgrad/nc_tev/nc_minv_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_minv_born_norec_200.dat\
              wzgrad/nc_tev/nc_minv_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-minv.eps "

system "epstopdf figures_TeV/born-TeV-Z-mu-bare-minv.eps"


###############################################################
# Tevatron Z  production  born  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'Tevatron' at 120,1.006
set label 'bare cuts' at 120,1.004
set label 'muon' at 120,1.002

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_minv_born_norec_200.dat\
              wzgrad/nc_tev/nc_minv_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_minv_born_norec_200.dat\
              wzgrad/nc_tev/nc_minv_tev.dat"\
      u 4:($5/$2) w his lw 2 lt 2 title '{\tt ZGRAD}'
unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-minv_ratio.eps "

system "epstopdf figures_TeV/born-TeV-Z-mu-bare-minv_ratio.eps"



###############################################################
# Tevatron Z  production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 30,6
set label 'bare cuts' at 30,5
set label 'muon' at 30,4

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptl1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptl1_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptl1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptl1_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-ptl.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-ptl.eps"


###############################################################
# Tevatron Z  production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 30,1.006
set label 'bare cuts' at 30,1.004
set label 'muon' at 30,1.002

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptl1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptl1_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptl1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptl1_tev.dat"\
      u 4:($5/$2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-ptl_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-ptl_ratio.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_costh*2_born_norec_200.dat\
              wzgrad/nc_tev/nc_costl1_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_costh*2_born_norec_200.dat\
              wzgrad/nc_tev/nc_costl1_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-costh.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-costh.eps"


###############################################################
# Tevatron Z  production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,1.006
set label 'bare cuts' at 0,1.004
set label 'muon' at 0,1.002

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_costh*2_born_norec_200.dat\
              wzgrad/nc_tev/nc_costl1_tev.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_costh*2_born_norec_200.dat\
              wzgrad/nc_tev/nc_costl1_tev.dat"\
      u 4:($5/$2) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-costh_ratio.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-costh_ratio.eps"



################################################################
#  O(alpha)
################################################################



###############################################################
# Tevatron W+ production  oal  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_etal_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_etal.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-etal.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-etal.eps"

###############################################################
# Tevatron W+ production  oal  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,1.0006
set label 'bare cuts' at 0,1.0004
set label 'muon' at 0,1.0002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_etal_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_etal_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_etal.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-etal_ratio.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-etal_ratio.eps"



###############################################################
# Tevatron W+ production  oal  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,18
set label 'muon' at 55,16

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_mtv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_MTln.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-mtw.eps "

system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-mtw.eps"

###############################################################
# Tevatron W+ production  oal  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,1.006
set label 'bare cuts' at 55,1.004
set label 'muon' at 55,1.002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_mtv1_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_mtv1_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_MTln.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-mtw_ratio.eps "

system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-mtw_ratio.eps"




###############################################################
# Tevatron W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.001:50]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 5,20
set label 'bare cuts' at 5,17
set label 'muon' at 5,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptW1.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptW1.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptW1.eps"


###############################################################
# Tevatron W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.95:1.05]



set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
set label 'bare cuts' at 5,1.004
set label 'muon' at 5,1.002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv1_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv1_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_ptW1.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptW1_ratio.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptW1_ratio.eps"



###############################################################
# Tevatron W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
set yrange [0.001:50]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptW2.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptW2.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptW2.eps"


###############################################################
# Tevatron W+ production  oal  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
set yrange [0.95:1.05]



set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,1.006
set label 'bare cuts' at 55,1.004
set label 'muon' at 55,1.002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv2_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptv2_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_ptW2.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptW2_ratio.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptW2_ratio.eps"






###############################################################
# Tevatron W+ production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptl1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptlp.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptl.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptl.eps"

###############################################################
# Tevatron W+ production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
set yrange [0.95:1.05]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,1.0006
set label 'bare cuts' at 45,1.0004
set label 'muon' at 45,1.0002

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptl1_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptl1_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_ptlp.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptl_ratio.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptl_ratio.eps"


###############################################################
# Tevatron W+ production  oal  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptn1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptnu.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptnu.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptnu.eps"

###############################################################
# Tevatron W+ production  oal  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptn1_oal_norec_200.dat"\
      u 1:($2/$2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptn1_oal_norec_200.dat\
              wzgrad/cc_tev/cc_tev_bare_ptnu.dat"\
      u 1:($5/$2) w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptnu_ratio.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptnu_ratio.eps"








###############################################################
# Tevatron W/Z  ratios  oal  muon  bare    transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_xmt1_oal_norec_200.dat\
              horace/oal-TeV-Z-mu-bare/tev_z_mu_xmt2_oal_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-Xmt.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-Xmt.eps"


###############################################################
# Tevatron W/Z  ratios  oal  muon  bare    transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_M$'
set ylabel '$\frac{d\sigma_W/dX_M(W)}{d\sigma_Z/dX_M(Z)}$'
set label 'Tevatron' at 1,20
set label 'bare cuts' at 1,17
set label 'muon' at 1,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_xptl1_oal_norec_200.dat\
              horace/oal-TeV-Z-mu-bare/tev_z_mu_xptl2_oal_norec_200.dat"\
      u 1:($2/$5) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-Xptl.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-Xptl.eps"




###############################################################
# Tevatron W+ production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptl1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptlp.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptl.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptl.eps"


###############################################################
# Tevatron W+ production  oal  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_ptn1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ptnu.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-ptnu.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-ptnu.eps"



###############################################################
# Tevatron W+ production  oal  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-TeV-Wp-mu-bare/tev_w_mu_costh*_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_tev_bare_ctlp.dat"\
      u 1:2 w his lw 2 lt 2 title '{\tt WZGRAD} '

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Wp-mu-bare-costh.eps "
system "epstopdf figures_TeV/oal-TeV-Wp-mu-bare-costh.eps"




###############################################################
# Tevatron Z  production  oal  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'Tevatron' at 120,7
set label 'bare cuts' at 120,6
set label 'muon' at 120,5

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_minv_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-minv.eps "

system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-minv.eps"

###############################################################
# Tevatron Z  production  oal  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 30,6
set label 'bare cuts' at 30,5
set label 'muon' at 30,4

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_ptl1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-ptl.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-ptl.eps"



###############################################################
# Tevatron Z  production  oal  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_etal_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-etal.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-etal.eps"



###############################################################
# Tevatron Z  production  oal  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_yv_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-yz.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-yz.eps"


###############################################################
# Tevatron Z  production  oal  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_costh*2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-costh.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-costh.eps"





###############################################################
# Tevatron Z  production  oal  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 15,20
set label 'bare cuts' at 15,17
set label 'muon' at 15,14

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_ptv1_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-ptZ1.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-ptZ1.eps"



###############################################################
# Tevatron Z  production  oal  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/oal-TeV-Z-mu-bare/tev_z_mu_ptv2_oal_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/oal-TeV-Z-mu-bare-ptZ2.eps "
system "epstopdf figures_TeV/oal-TeV-Z-mu-bare-ptZ2.eps"







system "tar -cvzf figures_TeV.tgz figures_TeV/"

exit

###############################################################
# Tevatron W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptv1_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_ptW1_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptW1.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptW1.eps"



###############################################################
# Tevatron W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptv2_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste wzgrad/cc_tev/cc_ptW2_tev.dat"\
      u 1:($2) w his lw 2 lt 2 title '{\tt WGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptW2.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptW2.eps"




###############################################################
# Tevatron W+ production  born  muon  bare   photon energy
set autoscale
set output "plot.eps"

set key top right
set xrange [0:50]
#set yrange [0.9:1.35]

set xlabel '$E_{\gamma}$ (GeV) '
set ylabel '$\frac{d\sigma}{dE_\gamma}(pb/GeV)$'
set label 'Tevatron' at 25,20
set label 'bare cuts' at 25,17
set label 'muon' at 25,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_eneg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-Eg.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-Eg.eps"

###############################################################
# Tevatron W+ production  born  muon  bare   photon transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\gamma$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\gamma}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ptg.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ptg.eps"



###############################################################
# Tevatron W+ production  born  muon  bare   sqrt{R_lg}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$\sqrt{R_{l\gamma}}$  '
set ylabel '$\frac{d\sigma}{d\sqrt{R_{l\gamma}}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_sqrRlg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-sqrtRlg.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-sqrtRlg.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   log_10(R_lg)
set autoscale
set output "plot.eps"

set key top right
set xrange [-6:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(R_{l\gamma})$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(R_{l\gamma})}(pb)$'
set label 'Tevatron' at -4,20
set label 'bare cuts' at -4,17
set label 'muon' at -4,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_logRlg_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-logRlg.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-logRlg.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$y^{(1/3)}$  '
set ylabel '$\frac{d\sigma}{dy^{(1/3)}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ycr_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-ycr.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-ycr.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [-4:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(y)$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(y)}(pb)$'
set label 'Tevatron' at -2,20
set label 'bare cuts' at -2,17
set label 'muon' at -2,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_logy_born_norec_200.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Wp-mu-bare-logy.eps "
system "epstopdf figures_TeV/born-TeV-Wp-mu-bare-logy.eps"

###############################################################
# Tevatron Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 15,20
set label 'bare cuts' at 15,17
set label 'muon' at 15,14

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptZ1_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv1_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptZ1_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-ptZ1.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-ptZ1.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv2_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptZ2_tev.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}',\
     "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv2_born_norec_200.dat\
              wzgrad/nc_tev/nc_ptZ2_tev.dat"\
      u 4:($5) w his lw 2 lt 2 title '{\tt ZGRAD}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_TeV/born-TeV-Z-mu-bare-ptZ2.eps "
system "epstopdf figures_TeV/born-TeV-Z-mu-bare-ptZ2.eps"

