set terminal epslatex color dashed

set ytics autofreq
unset xlabel
unset ylabel
unset logscale
unset xrange
unset yrange
unset log y


###############################################################
# Tevatron W+ production  born  muon  bare      transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,18
set label 'muon' at 55,16

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_mtv1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-mtw.eps "

system "epstopdf figures/born-TeV-Wp-mu-bare-mtw.eps"

###############################################################
# Tevatron W+ production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptl1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ptl.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ptl.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    neutrino transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\nu$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\nu}}(pb/GeV)$'
set label 'Tevatron' at 45,20
set label 'bare cuts' at 45,17
set label 'muon' at 45,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptn1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ptnu.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ptnu.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_etal_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-etal.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-etal.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_costh*_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-costh.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-costh.eps"


###############################################################
# Tevatron W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptv1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ptW1.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ptW1.eps"



###############################################################
# Tevatron W+ production  born  muon  bare    W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptv2_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ptW2.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ptW2.eps"




###############################################################
# Tevatron W+ production  born  muon  bare   photon energy
set autoscale
set output "plot.eps"

set key top right
set xrange [0:50]
#set yrange [0.9:1.35]

set xlabel '$E_{\gamma}$ (GeV) '
set ylabel '$\frac{d\sigma}{dE_\gamma}(pb/GeV)$'
set label 'Tevatron' at 25,20
set label 'bare cuts' at 25,17
set label 'muon' at 25,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_eneg_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-Eg.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-Eg.eps"

###############################################################
# Tevatron W+ production  born  muon  bare   photon transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^\gamma$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{\gamma}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ptg_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ptg.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ptg.eps"



###############################################################
# Tevatron W+ production  born  muon  bare   sqrt{R_lg}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$\sqrt{R_{l\gamma}}$  '
set ylabel '$\frac{d\sigma}{d\sqrt{R_{l\gamma}}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_sqrRlg_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-sqrtRlg.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-sqrtRlg.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   log_10(R_lg)
set autoscale
set output "plot.eps"

set key top right
set xrange [-6:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(R_{l\gamma})$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(R_{l\gamma})}(pb)$'
set label 'Tevatron' at -4,20
set label 'bare cuts' at -4,17
set label 'muon' at -4,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_logRlg_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-logRlg.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-logRlg.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [0:1]
#set yrange [0.9:1.35]

set xlabel '$y^{(1/3)}$  '
set ylabel '$\frac{d\sigma}{dy^{(1/3)}}(pb)$'
set label 'Tevatron' at 0.3,20
set label 'bare cuts' at 0.3,17
set label 'muon' at 0.3,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_ycr_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-ycr.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-ycr.eps"


###############################################################
# Tevatron W+ production  born  muon  bare   y^{1/3}
set autoscale
set output "plot.eps"

set key top right
set xrange [-4:0]
#set yrange [0.9:1.35]

set xlabel '$\log_{10}(y)$  '
set ylabel '$\frac{d\sigma}{d\log_{10}(y)}(pb)$'
set label 'Tevatron' at -2,20
set label 'bare cuts' at -2,17
set label 'muon' at -2,14

plot "< paste horace/born-TeV-Wp-mu-bare/tev_w_mu_logy_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Wp-mu-bare-logy.eps "
system "epstopdf figures/born-TeV-Wp-mu-bare-logy.eps"




###############################################################
# Tevatron Z  production  born  muon  bare      invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:200]
#set yrange [0.9:1.35]

set xlabel '$M_{ll}$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{ll}}(pb/GeV)$'
set label 'Tevatron' at 120,7
set label 'bare cuts' at 120,6
set label 'muon' at 120,5

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_minv_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-minv.eps "

system "epstopdf figures/born-TeV-Z-mu-bare-minv.eps"

###############################################################
# Tevatron Z  production  born  muon  bare      lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 30,6
set label 'bare cuts' at 30,5
set label 'muon' at 30,4

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptl1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-ptl.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-ptl.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    lepton pseudo-rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\eta^l$  '
set ylabel '$\frac{d\sigma}{d\eta^l}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_etal_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-etal.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-etal.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    lepton-pair rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$y_Z$  '
set ylabel '$\frac{d\sigma}{dy_Z}(pb)$'
set label 'Tevatron' at 0,16
set label 'bare cuts' at 0,14
set label 'muon' at 0,12

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_yv_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-yz.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-yz.eps"


###############################################################
# Tevatron Z  production  born  muon  bare    lepton partonic angle
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.5:1.5]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at 0,40
set label 'bare cuts' at 0,30
set label 'muon' at 0,20

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_costh*2_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-costh.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-costh.eps"


###############################################################
# Tevatron Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 15,20
set label 'bare cuts' at 15,17
set label 'muon' at 15,14

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv1_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-ptZ1.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-ptZ1.eps"



###############################################################
# Tevatron Z  production  born  muon  bare    Z transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^{W}}(pb/GeV)$'
set label 'Tevatron' at 55,20
set label 'bare cuts' at 55,17
set label 'muon' at 55,14

plot "< paste horace/born-TeV-Z-mu-bare/tev_z_mu_ptv2_born_norec_100.dat"\
      u 1:($2) w his lw 2 lt 1 title '{\tt HORACE}'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures/born-TeV-Z-mu-bare-ptZ2.eps "
system "epstopdf figures/born-TeV-Z-mu-bare-ptZ2.eps"








system "tar -cvzf figures.tgz figures/"

