set terminal epslatex color dashed

set ytics autofreq
unset xlabel
unset ylabel
unset logscale
unset xrange
unset yrange
unset log y



###############################################################
# Tevatron W/Z ratio  QCD-NLO     lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
set yrange [0:10]

set xlabel '$X_p(Z)$  '
set ylabel '$\frac{d\sigma}{dX_p}(pb)$'
#set label 'Tevatron' at -0.15,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste powheg/Wp-TeV/XpW_NLO_TeV.dat powheg/Z-TeV/XpZ_NLO_TeV.dat"\
      u 1:($2/$5) w his lw 4 lt 1 title '{\tt POWHEG NLO }',\
     "< paste powheg/Wp-TeV/XpW_POWHEG+HERWIG_TeV.dat\
              powheg/Z-TeV/XpZ_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$5) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG }',\
     "< paste powheg/Wp-TeV/XpW_POWHEG+PYTHIA_TeV.dat\
              powheg/Z-TeV/XpZ_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2/$5) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA }'

unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/WZ_Xp_qcd_TeV.eps "

system "epstopdf figures_qcd/WZ_Xp_qcd_TeV.eps"

###############################################################
# Tevatron W/Z ratio  QCD-NLO     transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$X_m(Z)$  '
set ylabel '$\frac{d\sigma}{dX_m}(pb)$'
#set label 'Tevatron' at -0.15,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/XmW_NLO_TeV.dat powheg/Z-TeV/XmZ_NLO_TeV.dat"\
      u 1:($2/$5) w his lw 4 lt 1 title '{\tt POWHEG NLO }'
#,\
#     "< paste    powheg/Z-TeV/XmZ_POWHEG+HERWIG_TeV.dat"\
#      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
#     "< paste   powheg/Z-TeV/XmZ_POWHEG+PYTHIA_TeV.dat"\
#      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/WZ_Xm_qcd_TeV.eps "

system "epstopdf figures_qcd/WZ_Xm_qcd_TeV.eps"



exit

###############################################################
# Tevatron Z production  QCD-NLO     Z rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.2:1.2]
#set yrange [0.9:1.35]

set xlabel '$y_{l^+l^-}$  '
set ylabel '$\frac{d\sigma}{dy_{l^+l^-s}}(pb)$'
set label 'Tevatron' at -0.15,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/yz_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/yz_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste   powheg/Z-TeV/yz_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   florence/Z-TeV/yz_NLO_TeV.dat"\
      u ($1):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_yz_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_yz_qcd_TeV.eps"



###############################################################
# Tevatron Z production  QCD-NLO     Z rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.2:1.2]
set yrange [0.9:1.1]

set xlabel '$y_{l^+l^-}$  '
set ylabel '$\frac{d\sigma}{dy_{l^+l^-s}}(pb)$'
set label 'Tevatron' at -0.15,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/yz_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/yz_POWHEG+HERWIG_TeV.dat\
                powheg/Z-TeV/yz_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste   powheg/Z-TeV/yz_POWHEG+HERWIG_TeV.dat\
                powheg/Z-TeV/yz_NLO_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/yz_POWHEG+HERWIG_TeV.dat\
                florence/Z-TeV/yz_NLO_TeV.dat"\
      u ($4):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_yz_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_yz_qcd_TeV_ratio.eps"




exit

###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.1:300]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptW1_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   florence/Wp-TeV/ptW1_NLO_TeV.dat"\
      u ($1-0.125):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW1_NLO_TeV.eps "

system "epstopdf figures_qcd/Wp_ptW1_NLO_TeV.eps"


###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.99:1.01]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptW1_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptW1_NLO_TeV.dat\
                florence/Wp-TeV/ptW1_NLO_TeV.dat"\
      u ($4-0.125):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW1_NLO_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptW1_NLO_TeV_ratio.eps"







###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum NLO zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.1:60]

set log y

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/ptZ1_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   florence/Z-TeV/ptZ1_NLO_TeV.dat"\
      u ($1-0.125):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ1_NLO_TeV.eps "

system "epstopdf figures_qcd/Z_ptZ1_NLO_TeV.eps"


###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum NLO zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
set yrange [0.99:1.01]



set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/ptZ1_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/ptZ1_NLO_TeV.dat\
                florence/Z-TeV/ptZ1_NLO_TeV.dat"\
      u ($4-0.125):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ1_NLO_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_ptZ1_NLO_TeV_ratio.eps"



exit


###############################################################
# Tevatron Z production  QCD     lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]


set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/ptl_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/ptl_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptl_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste   florence/Z-TeV/ptl_NLO_TeV.dat"\
      u ($1):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptl_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_ptl_qcd_TeV.eps"


###############################################################
# Tevatron Z production  QCD     lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
set yrange [0:5]


set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/ptl_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/ptl_NLO_TeV.dat\
                powheg/Z-TeV/ptl_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptl_NLO_TeV.dat\
                powheg/Z-TeV/ptl_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste   powheg/Z-TeV/ptl_NLO_TeV.dat\
                florence/Z-TeV/ptl_NLO_TeV.dat"\
      u ($4):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptl_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_ptl_qcd_TeV_ratio.eps"



exit

###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum NLO large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
set yrange [0.001:30]

set log y

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/ptZ2_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   florence/Z-TeV/ptZ2_NLO_TeV.dat"\
      u ($1-0.125):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ2_NLO_TeV.eps "

system "epstopdf figures_qcd/Z_ptZ2_NLO_TeV.eps"


###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum NLO large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.1:180]



set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/ptZ2_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/ptZ2_NLO_TeV.dat\
                florence/Z-TeV/ptZ2_NLO_TeV.dat"\
      u ($4-0.125):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ2_NLO_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_ptZ2_NLO_TeV_ratio.eps"


exit




###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
set yrange [0.01:180]

set log y

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptW2_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   florence/Wp-TeV/ptW2_NLO_TeV.dat"\
      u ($1-0.125):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW2_NLO_TeV.eps "

system "epstopdf figures_qcd/Wp_ptW2_NLO_TeV.eps"


###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.1:180]



set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptW2_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptW2_NLO_TeV.dat\
                florence/Wp-TeV/ptW2_NLO_TeV.dat"\
      u ($4-0.125):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW2_NLO_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptW2_NLO_TeV_ratio.eps"




exit
###############################################################
# Tevatron W+ production  QCD     transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,20
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/mtw_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/mtw_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/mtw_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Wp-TeV/mtw_NLO_TeV.dat"\
      u ($1-0.25):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_mtw_qcd_TeV.eps "

system "epstopdf figures_qcd/Wp_mtw_qcd_TeV.eps"

###############################################################
# Tevatron W+ production  QCD     transverse mass
set autoscale
set output "plot.eps"

set key bot center
set xrange [50:100]
set yrange [0.7:1.1]

set xlabel '$m_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 55,1.05
#set label 'bare cuts' at 55,1.03
#set label 'muon' at 55,1.01

plot "< paste   powheg/Wp-TeV/mtw_NLO_TeV.dat\
                powheg/Wp-TeV/mtw_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/mtw_NLO_TeV.dat\
                powheg/Wp-TeV/mtw_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Wp-TeV/mtw_NLO_TeV.dat\
              florence/Wp-TeV/mtw_NLO_TeV.dat"\
      u ($4-0.25):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_mtw_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_mtw_qcd_TeV_ratio.eps"




exit

###############################################################
# Tevatron Z production  QCD   invariant mass
set autoscale
set output "plot.eps"

set key top left
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 55,3.5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/minv_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/minv_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/minv_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Z-TeV/minv_NLO_TeV.dat"\
      u ($1-0.5):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_minv_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_minv_qcd_TeV.eps"



###############################################################
# Tevatron Z production   QCD   invariant mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 55,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/minv_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/minv_NLO_TeV.dat\
                powheg/Z-TeV/minv_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/minv_NLO_TeV.dat\
                powheg/Z-TeV/minv_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Z-TeV/minv_NLO_TeV.dat\
              florence/Z-TeV/minv_NLO_TeV.dat"\
      u ($4-0.5):($5/1000/$2) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_minv_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_minv_qcd_TeV_ratio.eps"




###############################################################
# Tevatron W+ production  QCD     lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,25
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptl_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptl_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptl_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Wp-TeV/ptl_NLO_TeV.dat"\
      u ($1-0.05):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptl_qcd_TeV.eps "

system "epstopdf figures_qcd/Wp_ptl_qcd_TeV.eps"

###############################################################
# Tevatron W+ production  QCD     lepton transverse momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptl_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptl_NLO_TeV.dat\
                powheg/Wp-TeV/ptl_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptl_NLO_TeV.dat\
                powheg/Wp-TeV/ptl_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Wp-TeV/ptl_NLO_TeV.dat\
              florence/Wp-TeV/ptl_NLO_TeV.dat"\
      u ($4-0.05):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptl_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptl_qcd_TeV_ratio.eps"














###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum + shower zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptW1_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptW1_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW1_NLO+shower_TeV.eps "

system "epstopdf figures_qcd/Wp_ptW1_NLO+shower_TeV.eps"


###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum + shower zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptW1_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptW1_POWHEG+HERWIG_TeV.dat\
                powheg/Wp-TeV/ptW1_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW1_NLO+shower_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptW1_NLO+shower_TeV_ratio.eps"




###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum+shower large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,15
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptW2_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptW2_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW2_NLO+shower_TeV.eps "

system "epstopdf figures_qcd/Wp_ptW2_NLO+shower_TeV.eps"



###############################################################
# Tevatron W+ production  QCD-NLO     W transverse momentum+shower large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^W$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^W}(pb/GeV)$'
set label 'Tevatron' at 5,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptW2_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptW2_POWHEG+HERWIG_TeV.dat\
                powheg/Wp-TeV/ptW2_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptW2_NLO+shower_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptW2_NLO+shower_TeV_ratio.eps"







###############################################################
# Tevatron Z production  QCD-NLO     W rapidity
set autoscale
set output "plot.eps"

set key top right
set xrange [-1.2:1.2]
#set yrange [0.9:1.35]

set xlabel '$y_{l^+\nu_{l}}$  '
set ylabel '$\frac{d\sigma}{dy_{l^+\nu_{l}}}(pb)$'
set label 'Tevatron' at -0.15,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot     "< paste   florence/Wp-TeV/yw_NLO_TeV.dat"\
      u ($1):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_yw_qcd_TeV.eps "

system "epstopdf figures_qcd/Wp_yw_qcd_TeV.eps"




###############################################################
# Tevatron W+ production  QCD     lepton transverse missing  momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,25
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/ptnu_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptnu_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptnu_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Wp-TeV/ptnu_NLO_TeV.dat"\
      u ($1-0.05):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptnu_qcd_TeV.eps "

system "epstopdf figures_qcd/Wp_ptnu_qcd_TeV.eps"

###############################################################
# Tevatron W+ production  QCD     lepton transverse missing  momentum
set autoscale
set output "plot.eps"

set key top right
set xrange [25:55]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^l$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^l}(pb/GeV)$'
set label 'Tevatron' at 27,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/ptnu_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/ptnu_NLO_TeV.dat\
                powheg/Wp-TeV/ptnu_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/ptnu_NLO_TeV.dat\
                powheg/Wp-TeV/ptnu_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Wp-TeV/ptnu_NLO_TeV.dat\
              florence/Wp-TeV/ptnu_NLO_TeV.dat"\
      u ($4-0.05):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_ptnu_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_ptnu_qcd_TeV_ratio.eps"


###############################################################
# Tevatron W+ production  QCD     lepton pseudo rapidity
set autoscale
set output "plot.eps"

set key top left
#set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$\eta_l$ (GeV) '
set ylabel '$\frac{d\sigma}{d\eta_l}(pb)$'
set label 'Tevatron' at 0.4,150
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Wp-TeV/etal_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/etal_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/etal_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Wp-TeV/etal_NLO_TeV.dat"\
      u ($1-0.05):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_etal_qcd_TeV.eps "

system "epstopdf figures_qcd/Wp_etal_qcd_TeV.eps"


###############################################################
# Tevatron W+ production  QCD     lepton pseudo rapidity
set autoscale
set output "plot.eps"

set key top left
#set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$\eta_l$ (GeV) '
set ylabel '$\frac{d\sigma}{d\eta_l}(pb)$'
set label 'Tevatron' at 0.4,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Wp-TeV/etal_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Wp-TeV/etal_NLO_TeV.dat\
                powheg/Wp-TeV/etal_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Wp-TeV/etal_NLO_TeV.dat\
                powheg/Wp-TeV/etal_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Wp-TeV/etal_NLO_TeV.dat\
              florence/Wp-TeV/etal_NLO_TeV.dat"\
      u ($4-0.05):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Wp_etal_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Wp_etal_qcd_TeV_ratio.eps"






###############################################################
# Tevatron Z production  QCD-NLO     Z cos theta
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at -0.15,5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/costh_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO }',\
     "< paste   powheg/Z-TeV/costh_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/costh_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_costh_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_costh_qcd_TeV.eps"


###############################################################
# Tevatron Z production  QCD-NLO     Z cos theta
set autoscale
set output "plot.eps"

set key top right
set xrange [0.6:1.2]
#set yrange [0.9:1.35]

set xlabel '$\cos\theta^*$  '
set ylabel '$\frac{d\sigma}{d\cos\theta^*}(pb)$'
set label 'Tevatron' at -0.15,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/costh_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO }',\
     "< paste   powheg/Z-TeV/costh_NLO_TeV.dat\
                powheg/Z-TeV/costh_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/costh_NLO_TeV.dat\
                powheg/Z-TeV/costh_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_costh_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_costh_qcd_TeV_ratio.eps"










###############################################################
# Tevatron Z production  QCD    lepton pseudo rapidity
set autoscale
set output "plot.eps"

set key top right
#set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$\eta_l$ (GeV) '
set ylabel '$\frac{d\sigma}{d\eta_l}(pb)$'
set label 'Tevatron' at 55,20
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/etal_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/etal_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/etal_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste florence/Z-TeV/etal_NLO_TeV.dat"\
      u ($1-0.05):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_etal_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_etal_qcd_TeV.eps"



###############################################################
# Tevatron Z production  QCD    lepton pseudo rapidity
set autoscale
set output "plot.eps"

set key top right
#set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$\eta_l$ (GeV) '
set ylabel '$\frac{d\sigma}{d\eta_l}(pb)$'
set label 'Tevatron' at 55,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/etal_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/etal_NLO_TeV.dat\
                powheg/Z-TeV/etal_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/etal_NLO_TeV.dat\
                powheg/Z-TeV/etal_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}',\
     "< paste powheg/Z-TeV/etal_NLO_TeV.dat\
              florence/Z-TeV/etal_NLO_TeV.dat"\
      u ($4-0.05):($5/$2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_etal_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_etal_qcd_TeV_ratio.eps"



###############################################################
# Tevatron Z production  QCD     transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 55,3.5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/mtz_NLO_TeV.dat"\
      u 1:($2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/mtz_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/mtz_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'
#,\
#     "< paste florence/Z-TeV/mtz_NLO_TeV.dat"\
#      u ($1-0.25):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_mtz_qcd_TeV.eps "

system "epstopdf figures_qcd/Z_mtz_qcd_TeV.eps"



###############################################################
# Tevatron Z production   QCD     transverse mass
set autoscale
set output "plot.eps"

set key top right
set xrange [50:100]
#set yrange [0.9:1.35]

set xlabel '$m_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dM_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 55,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/mtz_NLO_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 1 title '{\tt POWHEG NLO}',\
     "< paste   powheg/Z-TeV/mtz_NLO_TeV.dat\
                powheg/Z-TeV/mtz_POWHEG+HERWIG_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/mtz_NLO_TeV.dat\
                powheg/Z-TeV/mtz_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'
#,\
#     "< paste florence/Z-TeV/mtz_NLO_TeV.dat"\
#      u ($1-0.25):($2/1000) w his lw 4 lt 4 title '{\tt Florence NLO}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_mtz_qcd_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_mtz_qcd_TeV_ratio.eps"






###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum + shower zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 10,3.5
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/ptZ1_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptZ1_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ1_NLO+shower_TeV.eps "

system "epstopdf figures_qcd/Z_ptZ1_NLO+shower_TeV.eps"

###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum + shower zoom
set autoscale
set output "plot.eps"

set key top right
set xrange [0:25]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 10,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/ptZ1_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptZ1_POWHEG+HERWIG_TeV.dat\
                powheg/Z-TeV/ptZ1_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ1_NLO+shower_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_ptZ1_NLO+shower_TeV_ratio.eps"



###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum + shower large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 20,3
#set label 'bare cuts' at 55,18
#set label 'muon' at 55,16

plot "< paste   powheg/Z-TeV/ptZ2_POWHEG+HERWIG_TeV.dat"\
      u 1:($2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptZ2_POWHEG+PYTHIA_TeV.dat"\
      u 1:($2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'



unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ2_NLO+shower_TeV.eps "

system "epstopdf figures_qcd/Z_ptZ2_NLO+shower_TeV.eps"



###############################################################
# Tevatron Z production  QCD-NLO     Z transverse momentum + shower large
set autoscale
set output "plot.eps"

set key top right
set xrange [0:100]
#set yrange [0.9:1.35]

set xlabel '$p_{\perp}^Z$ (GeV) '
set ylabel '$\frac{d\sigma}{dp_{\perp}^Z}(pb/GeV)$'
set label 'Tevatron' at 20,1.006
#set label 'bare cuts' at 55,1.004
#set label 'muon' at 55,1.002

plot "< paste   powheg/Z-TeV/ptZ2_POWHEG+HERWIG_TeV.dat"\
      u 1:($2/$2) w his lw 4 lt 2 title '{\tt POWHEG+HERWIG}',\
     "< paste   powheg/Z-TeV/ptZ2_POWHEG+HERWIG_TeV.dat\
                powheg/Z-TeV/ptZ2_POWHEG+PYTHIA_TeV.dat"\
      u 1:($5/$2) w his lw 4 lt 3 title '{\tt POWHEG+PYTHIA}'


unset label
unset output
unset log y
unset xrange
unset yrange

system "latex wrapper2.tex && dvips wrapper2.dvi -o && ps2epsi wrapper2.ps figures_qcd/Z_ptZ2_NLO+shower_TeV_ratio.eps "

system "epstopdf figures_qcd/Z_ptZ2_NLO+shower_TeV_ratio.eps"













system "tar -cvzf figures_qcd.tgz figures_qcd/"

